import { HiroPartialTheme } from '../../types';
import { OGIT } from '@hiro-graph/client';
export declare type Widgets = 'Welcome' | 'SessionList' | 'Demo' | 'TopContributors' | 'Statistic';
export interface Contributors {
    [key: string]: number;
}
/**
 * Basic Widget config
 */
export interface BaseWidgetConfig {
    size?: string | number;
    title?: string;
    as: Widgets;
}
/**
 * Advanced Widget config with automatic data loading
 */
export interface Me {
    id: string;
    accountId: string;
    email: string;
    displayName: string;
    roles: string[];
}
export interface WidgetProvider {
    openApp: (appId: string, options: any) => void;
    selectMe: () => Me;
    selectAppsIds: () => {
        [key: string]: string;
    };
    getEnvUrls: () => {
        [key: string]: string;
    };
}
export interface DashboardConfig {
    theme: HiroPartialTheme;
    widgets: Record<string, WidgetConfig>;
}
/**
 * Widgets
 */
export interface WelcomeWidgetConfig extends BaseWidgetConfig {
    as: 'Welcome';
}
export interface SessionListWidgetConfig extends BaseWidgetConfig {
    as: 'SessionList';
}
export interface DemoWidgetConfig extends BaseWidgetConfig {
    as: 'Demo';
}
export interface TopContributorsWidgetConfig extends BaseWidgetConfig {
    as: 'TopContributors';
}
export interface StatisticWidgetConfig extends BaseWidgetConfig {
    as: 'Statistic';
}
export declare type WidgetConfig = WelcomeWidgetConfig | SessionListWidgetConfig | DemoWidgetConfig | TopContributorsWidgetConfig | StatisticWidgetConfig;
export interface WidgetProps {
    as: Widgets;
}
export interface OgitSession extends OGIT.SafeNode {
    'ogit/title'?: string;
    '/teaching_issue_subject'?: string;
    '/teaching_step_progress'?: string;
    '/teaching_ki_progress'?: string;
    '/teaching_ownerId'?: string;
    '/teaching_conversion_ownerId'?: string;
    '/teaching_is_handedover'?: string;
    '/teaching_rooms'?: string;
    '/teaching_rooms_completed'?: string;
    '/teaching_steps'?: string;
    '/teaching_steps_deployed'?: string;
    'ogit/Knowledge/archived': string;
}
/**
 * Teaching Sessions Widget
 */
export interface SessionItemProps {
    session: OgitSession;
}
export interface ProgressBarProps {
    progress: number;
}
export interface ProgressBarChunkProps extends ProgressBarProps {
    active?: boolean;
}
export interface DetailsContainerItem {
    name: string;
    content: string;
}
