import React from 'react';
import { useLucene } from '../../hooks';
import { Box } from '../../../elements';
import { Loader } from '../../../modules';
import { useWidgetContext } from '../../context';
import { SessionsButton } from './SessionsButton';
import { SessionsButtonText } from './SessionsButtonText';
import { WidgetTitle } from '../../shared';
var configureQuery = function (type, accountId) {
    var baseQuery = '+(ogit\\/_type:"ogit/Knowledge/AcquisitionSession")';
    var filterQueries = {
        new: "+(-\\/teaching_ownerId:* -\\/teaching_is_handedover:\"true\" -ogit\\/Knowledge\\/archived:\"true\")",
        started: "+(+\\/teaching_ownerId:\"" + accountId + "\" -\\/teaching_without_issue:\"true\" -ogit\\/Knowledge\\/archived:\"true\")",
    };
    return {
        querystring: baseQuery + " " + filterQueries[type],
        params: { limit: -1, count: true },
    };
};
var formatNumber = function (n) {
    return Math.floor(n).toString().length > 4
        ? Math.floor(n / 1000) + "k"
        : n.toString();
};
export var Welcome = function () {
    var _a = useWidgetContext(), client = _a.client, _b = _a.provider, selectMe = _b.selectMe, selectAppsIds = _b.selectAppsIds, openApp = _b.openApp, title = _a.config.title;
    var me = selectMe();
    var newSessionsCountQuery = configureQuery('new');
    var startedSessionsCountQuery = configureQuery('started', me.accountId);
    var newSessionsCount = useLucene(client, newSessionsCountQuery, [
        0,
    ])[0];
    var startedSessionsCount = useLucene(client, startedSessionsCountQuery, [0])[0];
    var loading = newSessionsCount.loading || startedSessionsCount.loading;
    var error = newSessionsCount.error || startedSessionsCount.error;
    var atqId = selectAppsIds().atqId;
    var greeting = title + " " + (me.displayName || '') + "!";
    var formattedNewSessionsCount = formatNumber(newSessionsCount.result[0]);
    var formattedStartedSessionsCount = formatNumber(startedSessionsCount.result[0]);
    var content = error || (React.createElement(React.Fragment, null,
        React.createElement(Box, { floated: "left" },
            React.createElement(WidgetTitle, null, greeting)),
        React.createElement(Box, { floated: "left" },
            React.createElement("span", null, "Nice to have you here! Let\u2019s get some work done together!")),
        React.createElement("br", null),
        React.createElement(Box, { direction: "row", centered: "spaced" },
            React.createElement(SessionsButton, { text: "Start Teaching", btnType: "primary", onClick: function () { return openApp(atqId, { action: 'show-new-sessions' }); } },
                React.createElement(Box, null,
                    React.createElement(SessionsButtonText, { fontSize: "18px" }, "New Tasks"),
                    React.createElement(SessionsButtonText, { fontSize: "88px" }, formattedNewSessionsCount))),
            React.createElement(SessionsButton, { text: "Continue Teaching", btnType: "secondary", onClick: function () { return openApp(atqId, { action: 'show-started-sessions' }); } },
                React.createElement(Box, null,
                    React.createElement(SessionsButtonText, { fontSize: "18px" }, "Started Tasks"),
                    React.createElement(SessionsButtonText, { fontSize: "88px" }, formattedStartedSessionsCount))))));
    return (React.createElement(Box, { centered: true },
        content,
        React.createElement(Loader, { active: loading })));
};
